@@ -69,18 +69,6 @@ class PaymentType(Enum):
         return json.dumps(self, cls=PaymentEncoder)
 
 
-class RemoteCollectionType(BaseModel):
-    id: UUID
-    type: str
-
-    class Config:
-        validate_all = True
-        validate_assignment = True
-
-    def json(self):
-        return json.dumps(self, cls=PaymentEncoder)
-
-
 class PayerType(Enum):
     TYPE_HUMAN = 'human'
     TYPE_LEGAL = 'legal'
@@ -141,7 +129,6 @@ class PaymentData(BaseModel):
     amount: Optional[float]
     currency: CurrencyType
     type: Optional[PaymentType]
-    reason: Optional[constr(max_length=140)]
     notice_code: Optional[str]
     iud: str
     iuv: Optional[str]
@@ -304,8 +291,8 @@ class Payment(BaseModel):
     created_at: str
     updated_at: str
     status: PaymentStatus
-    fault: Optional[Fault]
-    remote_collection: RemoteCollectionType
+    reason: Optional[constr(max_length=140)]
+    remote_id: UUID
     payment: PaymentData
     links: Links
     payer: Payer
@@ -386,7 +373,7 @@ class Payment(BaseModel):
 
     def is_payment_creation_needed(self):
         if self.status != PaymentStatus.STATUS_CREATION_PENDING:
-            logger.info(f'Event {self.id} from application {self.remote_collection.id}: Payment creation not required')
+            logger.info(f'Event {self.id} from application {self.remote_id}: Payment creation not required')
             return False
         return True
 
