@@ -157,11 +157,8 @@ def get_payment_event_data(**kwargs):
         'created_at': '2024-02-19T15:50:23+01:00',
         'updated_at': '2024-02-20T15:05:16+01:00',
         'status': 'PAYMENT_PENDING',
-        'fault': None,
-        'remote_collection': {
-            'id': '218d7772-a747-4d5f-8c56-bbc7cfeab1a0',
-            'type': 'application',
-        },
+        'remote_id': '218d7772-a747-4d5f-8c56-bbc7cfeab1a0',
+        'reason': 'bla',
         'payment': {
             'transaction_id': None,
             'paid_at': None,
@@ -169,7 +166,6 @@ def get_payment_event_data(**kwargs):
             'amount': 16,
             'currency': 'EUR',
             'type': 'STAMP',
-            'reason': 'bla',
             'notice_code': '001550000000024427',
             'iud': '68dada7823984a11b80a98aaede3371c',
             'iuv': '550000000024427',
