@@ -53,20 +53,18 @@ class PaymentTestCase(TestCase):
         self.assertEqual(payment.id, UUID('bb7044e4-066c-4bf7-915e-87ee97270eae'))
         self.assertEqual(payment.user_id, UUID('f3323b10-db62-4aeb-95de-a87c1f678dad'))
         self.assertEqual(payment.tenant_id, UUID('60e35f02-1509-408c-b101-3b1a28109329'))
-        self.assertEqual(payment.remote_collection.id, UUID('218d7772-a747-4d5f-8c56-bbc7cfeab1a0'))
-        self.assertEqual(payment.remote_collection.type, 'application')
+        self.assertEqual(payment.remote_id, UUID('218d7772-a747-4d5f-8c56-bbc7cfeab1a0'))
         self.assertEqual(payment.created_at, datetime.fromisoformat('2024-02-19T15:50:23+01:00'))
         self.assertEqual(payment.updated_at, datetime.fromisoformat('2024-02-20T15:05:16+01:00'))
         self.assertEqual(payment.status, PaymentStatus.STATUS_PAYMENT_PENDING)
-        self.assertIsNone(payment.fault)
-        self.assertEqual(payment.remote_collection.id, UUID('218d7772-a747-4d5f-8c56-bbc7cfeab1a0'))
+        self.assertEqual(payment.remote_id, UUID('218d7772-a747-4d5f-8c56-bbc7cfeab1a0'))
+        self.assertEqual(payment.reason, 'bla')
         self.assertEqual(payment.payment.transaction_id, None)
         self.assertIsNone(payment.payment.paid_at)
         self.assertEqual(payment.payment.expire_at, datetime.fromisoformat('2023-09-04T11:59:05+02:00'))
         self.assertEqual(payment.payment.amount, 16)
         self.assertEqual(payment.payment.currency, CurrencyType.CURRENCY_EUR)
         self.assertEqual(payment.payment.type, PaymentType.TYPE_STAMP)
-        self.assertEqual(payment.payment.reason, 'bla')
         self.assertEqual(payment.payment.notice_code, '001550000000024427')
         self.assertEqual(payment.payment.iud, '68dada7823984a11b80a98aaede3371c')
         self.assertEqual(payment.payment.iuv, '550000000024427')
@@ -162,50 +160,7 @@ class PaymentTestCase(TestCase):
         with self.assertRaises(ValidationError):
             Payment(
                 **get_payment_event_data(
-                    payment={
-                        'transaction_id': None,
-                        'paid_at': None,
-                        'expire_at': '2023-09-04T11:59:05+02:00',
-                        'amount': 16,
-                        'currency': 'EUR',
-                        'type': 'STAMP',
-                        'reason': 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt '  # noqa
-                        'ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco '  # noqa
-                        'laboris nisi ut aliquip ex ea commodo consequat.',
-                        'notice_code': '001550000000024427',
-                        'iud': '68dada7823984a11b80a98aaede3371c',
-                        'iuv': '550000000024427',
-                        'receiver': {
-                            'tax_identification_number': '777777777',
-                            'name': 'Comune di BlaBla',
-                            'iban': 'IT60X0542811101000000123456',
-                            'address': 'Via Del Campo',
-                            'building_number': '12',
-                            'postal_code': '38022',
-                            'town_name': 'Roma',
-                            'country_subdivision': 'RM',
-                            'country': 'IT',
-                        },
-                        'due_type': 'TARI',
-                        'pagopa_category': '9/12129/TS',
-                        'document': {
-                            'id': '123',
-                            'ref': 'http://example.com/api/documents/123',
-                            'hash': 'sha256:12398r4o32kjm534om543523489k23jn',
-                        },
-                        'split': [
-                            {
-                                'code': 'c_1',
-                                'amount': 0.5,
-                                'meta': {},
-                            },
-                            {
-                                'code': 'c_2',
-                                'amount': 0.5,
-                                'meta': {},
-                            },
-                        ],
-                    },
+                    reason='Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. ',  # noqa
                 ),
             )
 
